import React, { useState, useRef, useContext } from 'react'
import { useDrag, useDrop, DndProvider } from 'react-dnd'
import { GlobalStore } from '../index'
import styles from './index.less'

const getNanoid = (len = 10) => {
  var orgStr = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
  let returnStr = "";
  for (var i = 0; i < len; i++) {
    returnStr += orgStr.charAt(Math.floor((Math.random() * orgStr.length)));
  }
  return `${returnStr}`
}

const Group = (props) => {

  const id = getNanoid()
  const ref = useRef(null)

  const [{ dragging }, drag, dragPreview] = useDrag({
    type: 'box',
    item: {
      id: id,
      name: '通栏布局',
      widget: '通栏布局',
      children: []
    },
    collect(monitor) {
      return {
        dragging: monitor.isDragging()
      }
    }
  });

  drag(ref)

  const boxClick = () => {
    props?.boxClick?.()
  }

  return (
    <div
      ref={ref}
      className={styles.group}
      style={{ border: dragging ? '2px solid #001bff' : '' }}
      onClick={() => boxClick()}
    >
    </div>
  )
}


//111
const Card = (props) => {

  const ref = useRef(null)
  const id = getNanoid()

  const [{ dragging }, drag] = useDrag({
    type: 'card',
    item: {
      id: id,
      name: props.name,
      widget: props.widget,
    },
  })

  drag(ref)

  return (
    <div
      ref={ref}
      className={styles.card}
    >
      <div
        className={styles.cardBox}
        widget={props.widget}
      >
      </div>
    </div>
  )
}

const Left = () => {

  return (
    <div className={styles.left}>
      <div className={styles.header}>组件库</div>
      <div className={styles['l-content']}>
        <div className={styles.item}>
          <div className={styles['g-title']}>布局</div>
          <div className={styles['g-content']}>
            <Group></Group>
          </div>
        </div>
        <div className={styles.item}>
          <div className={styles['g-title']}>卡片组件</div>
          <div className={styles['g-content']}>
            <div>运营总览</div>
            <Card name={'运营总览'} widget={'OVERVIEW'}></Card>
            <div>水厂</div>
            <Card name={'水厂总览'} widget={'WATER_OVERVIEW'}></Card>
            <Card name={'供水量曲线'} widget={'WATER_CHART'}></Card>
            <div>管网</div>
            <Card name={'管网监控'} widget={'PIPEMONITORING'}></Card>
            <Card name={'管网采集'} widget={'PIPEGATHER'}></Card>
            <Card name={'管网巡检'} widget={'PIPEINSPECTION'}></Card>
            <Card name={'维修工单'} widget={'MAINTENANCEORDER'}></Card>
            <div>二供</div>
            <Card name={'二供总览'} widget={'OPERATIONAL_OVERVIEW'}></Card>
            <Card name={'泵房运行状态'} widget={'PUMP_STATUS'}></Card>
            <Card name={'泵房维修保养'} widget={'PUMP_MAINTAIN'}></Card>
            <div>营收</div>
            <Card name={'营收总览'} widget={'REVENUE_OVERVIEW'}></Card>
          </div>
        </div>
      </div>
    </div>
  )

}

export default Left